// @flow

import React from 'react'
import { ThemeProvider } from 'react-css-themr'
import Template from 'components/Template'
import Icon from 'components/Icon'
import Adapter from 'components/realestate/Adapter'
import theme from './theme.yml'

import {
  navItems,
  phone,
  footer,
  copyright,
  sections,
} from './data.yml'

const Phone = (props: {
  phone: string,
}) => (
  <div className="flex items-center white f4">
    <div className="mr2"><Icon name="fa-phone-square" /></div>
    <a className="link white" href={`tel:${props.phone}`}>{props.phone}</a>
  </div>
)

const Home = () => (
  <ThemeProvider theme={theme}>
    <Template
      theme={theme}
      items={navItems}
      rightNav={<Phone phone={phone} />}
      footer={{
        ...footer,
        items: navItems,
      }}
      copyright={copyright}
    >
      <div
        className="fixed bg-green br-100 pa2 w3 h3 z-9999 flex items-center justify-center animated infinite jello"
        style={{
          bottom: 20,
          right: 20,
        }}
      >
        <Icon name="fa-phone" className="f3 white" />
      </div>
      <div className="pt5">
        {sections.map(data => (
          <Adapter key={data.type} data={data} />
        ))}
      </div>
    </Template>
  </ThemeProvider>
)

export default Home
