// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import { defaultProps } from 'recompose'
import Nuka from 'nuka-carousel'
import Icon from 'components/Icon'

const PreviousButton = ({
  previousSlide,
  className,
}: {
  previousSlide: Function,
  goToSlide: Function,
  currentSlide: number,
  slideCount: number,
  className?: string,
}) => (
  <Icon
    name="fa-angle-left"
    className={className}
    onClick={() => {
      previousSlide()
    }}
  />
)

PreviousButton.defaultProps = {
  className: null,
}

const NextButton = ({
  nextSlide,
  className,
}: {
  nextSlide: Function,
  goToSlide: Function,
  currentSlide: number,
  slideCount: number,
  className?: string,
}) => (
  <Icon
    name="fa-angle-right"
    className={className}
    onClick={() => {
      nextSlide()
    }}
  />
)

NextButton.defaultProps = {
  className: undefined,
}

export const defaultStyles = {
  button: 'w1 h1 pointer bg-black-10 br-100 pa1',
}

class Carousel extends React.PureComponent {
  props: {
    slidesToShow?: number,
    items: Array<any>,
    renderItem: Function,
    theme: { [key: string]: string },
    className?: string,
  };

  static defaultProps = {
    slidesToShow: 1,
    className: undefined,
  };

  carousel: any;
  timeout: any;

  componentDidMount() {
    this.timeout = setTimeout(() => {
      this.carousel.setDimensions()
    }, 0)
  }

  componentWillUnmount() {
    clearTimeout(this.timeout)
  }

  render() {
    const {
      slidesToShow = 1,
      className,
      theme,
      items,
      renderItem,
      ...props
    } = this.props

    return (
      <div data-component="Carousel" className={cn(theme.root, className)}>
        <Nuka
          ref={(ref) => { this.carousel = ref }}
          slidesToShow={slidesToShow}
          decorators={[
            {
              component: () => null,
              position: 'BottomCenter',
            },
            {
              component: defaultProps({ className: theme.button })(PreviousButton),
              position: 'CenterLeft',
            },
            {
              component: defaultProps({ className: theme.button })(NextButton),
              position: 'CenterRight',
            },
          ]}
          {...props}
        >
          {items.map(x => renderItem(x))}
        </Nuka>
      </div>
    )
  }
}

export default themr('Carousel', {}, { composeTheme: 'softly' })(Carousel)
