// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import { Form } from 'react-form'
import TextInput from 'components/TextInput'

export const defaultStyles = {
  label: '',
  input: '',
  button: '',
}

const ContactForm = ({
  className,
  nameLabel,
  emailLabel,
  phoneLabel,
  descriptionLabel,
  submitLabel,
  onSubmit,
  onValidationFail,
  theme,
}: {
  className?: string,
  nameLabel?: string,
  emailLabel?: string,
  phoneLabel?: string,
  descriptionLabel?: string,
  submitLabel?: string,
  dispatch: Function,
  onSubmit: Function,
  onValidationFail?: Function,
  theme: { [key: string]: string },
}) => {
  const inputTheme = {
    root: theme.inputWrapper,
    icon: theme.icon,
    input: theme.input,
  }

  return (
    <Form
      data-component="ContactForm"
      className={className}
      onSubmit={onSubmit}
      onValidationFail={(...args) => onValidationFail && onValidationFail(...args)}
      validate={(values) => {
        const errors = {
          email: !values.email ? 'Email is required' : undefined,
          phone: !values.phone ? 'Phone is required' : undefined,
          name: !values.name ? 'Name is required' : undefined,
        }
        return errors
      }}
    >
      {({ submitForm, getError }) => (
        <div>
          <form
            className={theme.form}
            onSubmit={submitForm}
          >
            <TextInput
              icon="fa-user"
              type="text"
              field="name"
              className="flex-auto w-100"
              placeholder={nameLabel}
              theme={inputTheme}
            />
            <TextInput
              icon="fa-envelope-o"
              type="email"
              field="email"
              className="flex-auto w-100"
              placeholder={emailLabel}
              theme={inputTheme}
            />
            <TextInput
              icon="fa-phone"
              field="phone"
              className="flex-auto w-100"
              placeholder={phoneLabel}
              theme={inputTheme}
            />
            <TextInput
              icon="fa-pencil-square-o"
              field="description"
              multiline
              rows={5}
              className="flex-auto w-100"
              placeholder={descriptionLabel}
              theme={inputTheme}
            />
            <button className={theme.callToAction} type="submit">{submitLabel}</button>
          </form>
          <div className={theme.errorWrapper}>
            {(['name', 'email', 'phone', 'description']).map(item => (
              <div
                key={item}
                className={theme.error}
              >
                {getError(item)}
              </div>
            ))}
          </div>
        </div>
      )}
    </Form>
  )
}

ContactForm.defaultProps = {
  children: null,
  className: null,
  nameLabel: 'Name',
  emailLabel: 'Email',
  phoneLabel: 'Phone',
  descriptionLabel: 'Description',
  submitLabel: 'Submit',
  onValidationFail: null,
}

export default themr('ContactForm', {}, { composeTheme: 'softly' })(ContactForm)
