// @flow

import React from 'react'
import { compose, withState } from 'recompose'
import { themr } from 'react-css-themr'
import cn from 'classnames'
// import CSSTransitionGroup from 'react-transition-group/CSSTransitionGroup'
import Transition from 'react-motion-ui-pack'
// import { spring } from 'react-motion'

export const defaultStyles = {
  image: 'is-64x64 pa2',
  title: 'f5',
}

const FlipCard = ({
  item: { title, description, actions = [] },
  reverse,
  className,
  theme,
  Link,
  isFlip,
  flip,
}: {
  item: Item,
  reverse?: boolean,
  className?: string,
  theme: { [key: string]: string },
  Link: any,
  isFlip: boolean,
  flip: (isFlip: boolean) => void,
}) => (
  <div
    data-component="FlipCard"
    className={cn('flex flex-wrap items-center', theme.root, className, { 'flex-row-reverse': reverse })}
  >
    {!isFlip && (
      <Transition
        component={false}
        enter={{
          opacity: 1,
          translateY: 0, // spring(0, { stiffness: 80, damping: 10 }),
        }}
        leave={{
          opacity: 0,
          translateY: -100,
        }}
      >
        <div className={theme.body}>
          <div className={theme.title}>{title}</div>
          <div className={theme.description}>{description}</div>
          <div className={theme.footer}>
            {actions.length > 0 && actions.map(action => (
              <div className="h3 tc mt2 mt3-ns">
                <Link
                  className={cn('button', theme.action)}
                  to={action.href}
                >
                  {action.label}
                </Link>
              </div>
            ))}
          </div>
          <button onClick={() => flip(true)}>Flip</button>
        </div>
      </Transition>
    )}
    {isFlip && (
      <Transition
        component={false}
        enter={{
          opacity: 1,
          translateY: 0, // spring(0, { stiffness: 80, damping: 10 }),
        }}
        leave={{
          opacity: 0,
          translateY: 100,
        }}
      >
        <div key="back">
          Back
          <button onClick={() => flip(false)}>Flop</button>
        </div>
      </Transition>
      // <CSSTransitionGroup
      //   transitionEnterTimeout={500}
      //   transitionLeaveTimeout={300}
      //   transitionName={{
      //     enter: 'animated',
      //     enterActive: 'animated bounceIn',
      //     leave: 'animated bounceOut',
      //     leaveActive: 'animated bounceOut',
      //     appear: 'animated',
      //     appearActive: 'animated bounceIn',
      //   }}
      // >
      // </CSSTransitionGroup>
    )}
  </div>
)

FlipCard.defaultProps = {
  className: null,
  reverse: false,
}

export default compose(
  themr('FlipCard', {}, { composeTheme: 'softly' }),
  withState('isFlip', 'flip', false),
)(FlipCard)
