// @flow

import React from 'react'
import { storiesOf } from '@kadira/storybook'
import Wrapper from 'components/Wrapper'
import LabelValue, { defaultStyles } from './'
import { withLabel, withIcon, withLabelAndIcon } from './data.yml'

storiesOf('Label Value', module)
  .addWithInfo(
    'default',
    `
      Display a label (or icon), value. Useful for customize listing. Example (real estate summary)
    `,
    () => (
      <div>
        <Wrapper className="mb3" title="With Label">
          {withLabel.map(({ icon, label, value }) => (
            <LabelValue
              key={label}
              theme={defaultStyles}
              icon={icon}
              label={label}
              value={value}
            />
          ))}
        </Wrapper>
        <Wrapper className="mb3" title="With Icon">
          {withIcon.map(({ key, icon, label, value }) => (
            <LabelValue
              key={key}
              theme={{
                ...defaultStyles,
                label: 'w2 -blue',
              }}
              icon={icon}
              label={label}
              value={value}
            />
          ))}
        </Wrapper>
        <Wrapper className="mb3" title="With Label & Icon">
          {withLabelAndIcon.map(({ key, icon, label, value }) => (
            <LabelValue
              key={key}
              theme={{
                ...defaultStyles,
                icon: 'mr2',
                label: 'w4 pa1 b -blue',
              }}
              icon={icon}
              label={label}
              value={value}
            />
          ))}
        </Wrapper>
      </div>
    ),
  )
