// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import { Link as ScrollLink } from 'react-scroll'
import cn from 'classnames'
import { getLinkComponent } from 'components/config'

const Link = ({ to, children, isScroll, className, theme, ...props }: {
  to: string,
  isScroll: boolean,
  children?: any,
  className?: string,
  theme: { [key: string]: string },
}) => {
  const BaseLink = getLinkComponent()
  const linkProps = {
    'data-component': isScroll ? 'ScrollLink' : 'Link',
    className: cn('link', className, theme.root),
    to,
    ...props,
  }

  if (!isScroll) return <BaseLink {...linkProps}>{children}</BaseLink>
  return <ScrollLink {...linkProps}>{children}</ScrollLink>
}

Link.defaultProps = {
  children: null,
  isScroll: false,
  className: undefined,
}

export default themr('Link', {}, { composeTheme: 'softly' })(Link)
