// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import Link from 'components/Link'
import LanguageSelector from 'components/LanguageSelector'

const NavDropdown = ({
  items,
  languages = [],
  language,
  rightSection,
  onClose,
  theme,
  className,
  ...props
}: {
  items: Array<{
    to: string,
    label: any,
  }>,
  languages: Array<{
    lang: string,
    link: string,
  }>,
  language: string,
  rightSection?: string,
  theme: { [key: string]: string },
  className?: string,
  onClose: () => void,
}) => (
  <div
    className={cn('min-h-100', theme.root, className)}
    data-component="NavDropdown"
    {...props}
  >
    <div className={theme.body}>
      {items.map(item => (
        <Link
          key={item.to}
          className={theme.item}
          to={item.to}
          onClick={() => onClose()}
        >
          {item.label}
        </Link>
      ))}
      {languages.length > 0 && (
        <LanguageSelector
          selected={language}
          items={languages}
        />
      )}
      {rightSection}
    </div>
  </div>
)

NavDropdown.defaultProps = {
  className: undefined,
  phone: undefined,
}

export default themr('NavDropdown', {}, { composeTheme: 'softly' })(NavDropdown)
