// @flow

import React from 'react'
import cn from 'classnames'
import Link from 'components/Link'
import ProgressiveImage from 'react-progressive-image'
import { themr } from 'react-css-themr'

export const defaultStyles = {
  root: '',
}

const PostCard = ({
  item,
  readMoreText = 'Read more',
  theme,
  className,
}: {
  item: TPost,
  readMoreText?: string,
  className?: string,
  theme: { [key: string]: string }
}) => (
  <div className={cn('flex flex-column', theme.root, className)}>
    <div className={theme.imageWrapper}>
      <ProgressiveImage src={item.image} placeholder={item.smallImage}>
        {src => <img className={theme.image} src={src} alt={item.title} />}
      </ProgressiveImage>
    </div>
    <div className={theme.metaWrapper}>
      <div className={theme.meta}>
        <div className={theme.category}>
          <Link to={item.category.slug}>{item.category.name}</Link>
        </div>
        <span className={theme.metaSeparator}>-</span>
        <div className={theme.date}>
          {item.date}
        </div>
      </div>
    </div>
    <div className={theme.titleWrapper}>
      <Link className={theme.title} to={item.slug}>
        {item.title}
      </Link>
    </div>
    <div className="flex justify-center">
      <div className="flex-auto" />
      <hr className={cn('flex-none', theme.hr)} />
      <div className="flex-auto" />
    </div>
    <div className={theme.descriptionWrapper}>
      <div className={theme.description}>{item.description}</div>
    </div>
    <div className={theme.readMoreWrapper}>
      <Link className={theme.readMore} to={item.slug}>
        {readMoreText}
      </Link>
    </div>
  </div>
)

PostCard.defaultProps = {
  className: undefined,
  readMoreText: 'Read More',
}

export default themr('PostCard', {}, { composeTheme: 'softly' })(PostCard)
