// @flow

import React from 'react'
import SectionWithData from 'components/SectionWithData'
import SplitSection from 'components/SplitSection'

const Sections = ({
  sections,
  className,
  themes,
  Link,
}: {
  sections: Array<TSection>,
  className?: string,
  themes: Array<{
    id: string,
    theme: { [key: string]: string },
    childrenTheme: { [key: string]: string },
  }>,
  Link: any,
}) => {
  const keys = sections.map(x => x.id)
  const sectionMap = sections.reduce((acc, value) => ({
    ...acc,
    [value.id]: value,
  }), {})
  const themeMap = themes.reduce((acc, value) => ({
    ...acc,
    [value.id]: value,
  }), {})

  return (
    <div
      data-component="Sections"
      className={className}
    >
      {keys.map((key) => {
        const themeId = sectionMap[key].themeId || key
        const type = sectionMap[key].type
        const { theme = {}, childrenTheme = {} } = themeMap[themeId] || {}
        if (type === 'split') {
          return (
            <SplitSection
              key={key}
              section={sectionMap[key]}
              theme={theme}
              childrenTheme={childrenTheme}
              Link={Link}
            />
          )
        }
        return (
          <SectionWithData
            key={key}
            section={sectionMap[key]}
            theme={theme}
            childrenTheme={childrenTheme}
            Link={Link}
          />
        )
      })}
    </div>
  )
}

Sections.defaultProps = {
  className: null,
}

export default Sections
