// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import { Element } from 'react-scroll'
import Markdown from 'react-markdown'
import Section from 'components/Section'
import Icon from 'components/Icon'

const Location = ({ data, theme }: {
  data: any,
  theme: { [key: string]: string },
}) => {
  const { element, title, subtitle, description, items } = data
  const section = (
    <Section
      title={title}
      subtitle={subtitle}
      theme={theme}
    >
      <div className={theme.imageWrapper}>
        <img
          alt="map"
          src={data.image}
        />
      </div>
      <div className={theme.textWrapper}>
        <div className={theme.description}>
          <Markdown source={description} />
        </div>
        {items.map(item => (
          <div
            key={item.label}
            className={theme.itemWrapper}
          >
            <div className={theme.item}>
              <div className={theme.iconWrapper}>
                <Icon name={item.icon} className={theme.icon} />
              </div>
              <div className={theme.label}>{item.label}</div>
            </div>
          </div>
        ))}
      </div>
    </Section>
  )

  if (!element) return section

  return (
    <Element name={element}>
      {section}
    </Element>
  )
}

export default themr('Location', {}, { composeTheme: 'softly' })(Location)
