// @flow

import React from 'react'
import R from 'ramda'
import { themr } from 'react-css-themr'
import { Element } from 'react-scroll'
import Section from 'components/Section'
import LabelValue from 'components/LabelValue'

const removeEmpty = R.pickBy(v => !!v)

const Pricing = ({ data, theme }: {
  data: any,
  theme: { [key: string]: string },
}) => {
  const { element, title, subtitle, pricing, bankSupport } = data
  const section = (
    <Section
      title={title}
      subtitle={subtitle}
      theme={theme}
    >
      <div className={theme.pricingWrapper}>
        <h3>{pricing.title}</h3>
        {pricing.items.map(({ icon, value }) => (
          <LabelValue
            key={value}
            icon={icon}
            value={value}
            theme={removeEmpty({
              root: theme.pricingItem,
              icon: theme.pricingItemIcon,
              label: theme.pricingItemLabel,
              value: theme.pricingItemValue,
            })}
          />
        ))}
      </div>
      <div className={theme.bankWrapper}>
        <h3>{bankSupport.title}</h3>
        {bankSupport.items.map(({ icon, label, value }) => (
          <LabelValue
            key={value}
            icon={icon}
            label={label}
            value={value}
            theme={removeEmpty({
              root: theme.bankItem,
              icon: theme.bankItemIcon,
              label: theme.bankItemLabel,
              value: theme.bankItemValue,
            })}
          />
        ))}
      </div>
    </Section>
  )

  if (!element) return section

  return (
    <Element name={element}>
      {section}
    </Element>
  )
}

export default themr('Pricing', {}, { composeTheme: 'softly' })(Pricing)
